@@ -61,7 +61,6 @@ class MovieParser:
 
         extra = []
         tag_keywords = {
-            # Release groups / encoders
             'psa': 'PSA',
             'pahe': 'Pahe',
             'galaxyrg': 'GalaxyRG',
@@ -85,7 +84,6 @@ class MovieParser:
             'iht': 'IHT',
             'amzn-rls': 'Amazon Release',
 
-            # Streaming platforms
             'nf': 'Netflix',
             'amzn': 'Amazon',
             'hmax': 'HBO Max',
@@ -100,7 +98,6 @@ class MovieParser:
             'atvp': 'Apple TV+',
             'mbc': 'MBC',
 
-            # Video quality / features
             'imax': 'IMAX',
             'hdr': 'HDR',
             'hdr10': 'HDR10',
@@ -113,13 +110,8 @@ class MovieParser:
             '10bit': '10bit',
             '8bit': '8bit',
             'hevc': 'HEVC',
-            'x265': 'x265',
-            'h265': 'H.265',
-            'x264': 'x264',
-            'h264': 'H.264',
             'av1': 'AV1',
 
-            # Audio formats
             'aac': 'AAC',
             'aac2': 'AAC2.0',
             'aac5': 'AAC5.1',
@@ -138,24 +130,6 @@ class MovieParser:
             'mp3': 'MP3',
             'lpcm': 'LPCM',
 
-            # Sources
-            'bluray': 'BluRay',
-            'brrip': 'BRRip',
-            'bdrip': 'BDRip',
-            'webrip': 'WEBRip',
-            'webdl': 'WEB-DL',
-            'hdtv': 'HDTV',
-            'dvdrip': 'DVDRip',
-            'dvdscr': 'DVDScr',
-            'r5': 'R5',
-            'cam': 'CAM',
-            'ts': 'TS',
-            'telesync': 'Telesync',
-            'telecine': 'Telecine',
-            'screener': 'Screener',
-            'vhsrip': 'VHSRip',
-
-            # Misc release tags
             'remux': 'Remux',
             'repack': 'Repack',
             'rerip': 'ReRip',
@@ -168,7 +142,6 @@ class MovieParser:
             'festival': 'Festival Cut',
             'sample': 'Sample',
 
-            # Scene vanity / oddball
             '1337x': '1337x',
             'eztv': 'EZTV',
             'torrentgalaxy': 'TorrentGalaxy',
